# This file was auto-generated by Fern from our API Definition.

import typing

from .configured_transformation_item_component_one import ConfiguredTransformationItemComponentOne

ConfiguredTransformationItemComponent = typing.Union[
    typing.Dict[str, typing.Any], ConfiguredTransformationItemComponentOne
]
