# This file was auto-generated by Fern from our API Definition.

import typing

from ....types.chroma_vector_store import ChromaVectorStore
from ....types.pg_vector_store import PgVectorStore
from ....types.pinecone_vector_store import PineconeVectorStore
from ....types.qdrant_vector_store import QdrantVectorStore
from ....types.weaviate_vector_store import WeaviateVectorStore

DataSinkUpdateComponentOne = typing.Union[
    ChromaVectorStore, PineconeVectorStore, PgVectorStore, QdrantVectorStore, WeaviateVectorStore
]
