# This file was auto-generated by Fern from our API Definition.

import typing

from .llm import Llm
from .llm_predictor import LlmPredictor

QuestionsAnsweredExtractorLlm = typing.Union[LlmPredictor, Llm]
