# This file was auto-generated by Fern from our API Definition.

from .types import DataSinkUpdateComponent, DataSinkUpdateComponentOne

__all__ = ["DataSinkUpdateComponent", "DataSinkUpdateComponentOne"]
