# This file was auto-generated by Fern from our API Definition.

import typing

from .data_sink_create_component_one import DataSinkCreateComponentOne

DataSinkCreateComponent = typing.Union[typing.Dict[str, typing.Any], DataSinkCreateComponentOne]
