# This file was auto-generated by Fern from our API Definition.

import typing

from ....types.beautiful_soup_web_reader import BeautifulSoupWebReader
from ....types.discord_reader import DiscordReader
from ....types.document import Document
from ....types.document_group import DocumentGroup
from ....types.elasticsearch_reader import ElasticsearchReader
from ....types.google_docs_reader import GoogleDocsReader
from ....types.google_sheets_reader import GoogleSheetsReader
from ....types.notion_page_reader import NotionPageReader
from ....types.reader_config import ReaderConfig
from ....types.rss_reader import RssReader
from ....types.simple_web_page_reader import SimpleWebPageReader
from ....types.slack_reader import SlackReader
from ....types.text_node import TextNode
from ....types.trafilatura_web_reader import TrafilaturaWebReader
from ....types.twitter_tweet_reader import TwitterTweetReader
from ....types.wikipedia_reader import WikipediaReader
from ....types.youtube_transcript_reader import YoutubeTranscriptReader

DataSourceUpdateComponentOne = typing.Union[
    Document,
    TextNode,
    DiscordReader,
    ElasticsearchReader,
    NotionPageReader,
    SlackReader,
    TwitterTweetReader,
    SimpleWebPageReader,
    TrafilaturaWebReader,
    BeautifulSoupWebReader,
    RssReader,
    WikipediaReader,
    YoutubeTranscriptReader,
    GoogleDocsReader,
    GoogleSheetsReader,
    ReaderConfig,
    DocumentGroup,
]
