# This file was auto-generated by Fern from our API Definition.

import typing

from .data_source_create_component_one import DataSourceCreateComponentOne
from .externally_stored_component import ExternallyStoredComponent

DataSourceCreateComponent = typing.Union[
    typing.Dict[str, typing.Any], DataSourceCreateComponentOne, ExternallyStoredComponent
]
