# This file was auto-generated by Fern from our API Definition.

import typing

from ....types.externally_stored_component import ExternallyStoredComponent
from .data_source_update_component_one import DataSourceUpdateComponentOne

DataSourceUpdateComponent = typing.Union[
    typing.Dict[str, typing.Any], DataSourceUpdateComponentOne, ExternallyStoredComponent
]
